#!/usr/bin/env python
# 
# Michael McKerns
# mmckerns@caltech.edu 
from distutils.core import setup, Extension
from sys import platform
import os

#check environment variables...
try:
    numarrayversion = ''
    import numarray
except ImportError:
    raise "numarray %r+ is required" % numarrayversion
try:
    idl_version = os.environ['IDL_VERSION']
except KeyError:
    raise "set enviroment variable 'IDL_VERSION' to the idl version number"
try:
    idl_incdir = os.environ['IDL_INCDIR']
except KeyError:
    raise "set enviroment variable 'IDL_INCDIR' to idl's include directory"
try:
    idl_libdir = os.environ['IDL_BINDIR']
except KeyError:
    raise "set enviroment variable 'IDL_BINDIR' to idl's binary lib directory"

if platform[:3] == 'win':
    IDLLIBS = ['idl32']
    module1 = Extension('_pyIDL',
                       ['module\\bindings.cc',
                        'module\_pyIDLmodule.cc',
                        'module\pyIDL.cc'],
                       include_dirs=['module', idl_incdir],
                       libraries=IDLLIBS,
                       library_dirs=[idl_libdir],
                       )
else: #platform = linux or mac
    try:
        x11_libdir = os.environ['X11_LIBDIR']
    except KeyError:
        raise "set enviroment variable 'X11_LIBDIR' to X11's library directory"

    if float(idl_version) >= float('6.3'):
        IDLLIBS = ['idl','Xm','Xp','Xpm','Xmu','Xext','Xt','SM','ICE',
                   'Xinerama','X11','dl','termcap','rt','m','pthread','gcc_s'] 
    else: #6.0 to 6.2
        IDLLIBS = ['idl','Xm','Xp','Xpm','Xext','Xt','SM','ICE','X11',
                   'dl','termcap','rt','m','pthread'] 

    if platform[:6] == 'darwin':
        IDLLIBS.remove('rt')
        IDLLIBS.append('MesaGL6_2')
        IDLLIBS.append('MesaGLU6_2')
        IDLLIBS.append('OSMesa6_2')
        IDLLIBS.append('freetype2_1_3')

    module1 = Extension('_pyIDLmodule',
                       ['module/bindings.cc',
                        'module/_pyIDLmodule.cc',
                        'module/pyIDL.cc'],
                       include_dirs=['module', idl_incdir],
                       libraries=IDLLIBS,
                       library_dirs=[x11_libdir, idl_libdir],
                       )

#build python module...
setup(name='pyIDL',
      version='0.6.0',
      description='Python bindings for ITT IDL',
      author = 'Mike McKerns',
      author_email = 'mmckerns@caltech.edu',
      url = 'http://www.its.caltech.edu/~mmckerns/software.html',
      packages=['pyIDL'],
      package_dir={'pyIDL':''},
      ext_modules=[module1],
      )

# end of file
